@@ -1,4 +1,4 @@
 from .Calculable import Calculable
 from .PolynomialSimple import PolynomialSimple
 from .PolynomialFraction import PolynomialFraction
-from .Expression import Expression
+# from .Expression import Expression
